import VPlay 1.0
import QtQuick 1.1

/*
To achieve a fast application start, try to keep the first scene as small as possible.
If that is no option, consider starting with a loading scene and use a Loader to load the first scene dynamically after displaying the loading scene.
In this demo, the first scene contains only the main menu, therefore loading it directly at application start is fine.
Every other Scene gets loaded dynamically when requested with the Loader in SceneLoader.qml.
Additionally a LoadingScene is displayed before loading the "big" GameScene.
*/
GameWindow { 
  id: window

  // the selected level of the SelectLevelScene gets stored here to be available for the GameScene, this is necessary because at the time the GameScene needs this information, the SelectLevelScene will already be unloaded
  property string selectedLevel

  // the loader for all the scenes
  SceneLoader {
    id: sceneLoader
  }

  // default state is menu -> default scene is menuScene
  state: "menu"

  // state machine is used to request the right scene from the SceneLoader
  states: [
    State {
      name: "menu"
      StateChangeScript {
        script: {
          sceneLoader.scene = "MenuScene.qml"
        }
      }
    },
    State {
      name: "selectLevel"
      StateChangeScript {
        script: {
          sceneLoader.scene = "SelectLevelScene.qml"
        }
      }
    },
    State {
      name: "credits"
      StateChangeScript {
        script: {
          sceneLoader.scene = "CreditsScene.qml"
        }
      }
    },
    State {
      name: "game"
      StateChangeScript {
        script: {
          sceneLoader.scene = "GameScene.qml"
        }
      }
    }
  ]
}
